@@ -1,14 +1,15 @@
 import os
 import sys
 from io import StringIO, BytesIO
-from typing import List, Optional
+from typing import TYPE_CHECKING
 
-import boto3
 import botocore
 
 from deci_common.abstractions.abstract_logger import ILogger
 from deci_common.aws_connection import AWSConnector
-from deci_common.decorators.explicit_params_validator import explicit_params_validation
+
+if TYPE_CHECKING:
+    from typing import Any, Dict, List, Optional, Union
 
 
 class KeyNotExistInBucketError(Exception):
@@ -24,7 +25,7 @@ class S3Connector(ILogger):
     S3Connector - S3 Connection Manager
     """
 
-    def __init__(self, env: str = None, bucket_name: str = None):
+    def __init__(self, env: "Optional[str]" = None, *, bucket_name: str):
         """
         Initiate a connector to AWS S3 object storage
         :param env: profile name or environment for the s3 client and resource
@@ -36,8 +37,7 @@ class S3Connector(ILogger):
         self.s3_client = AWSConnector.get_aws_client_for_service_name(profile_name=env, service_name="s3")
         self.s3_resource = AWSConnector.get_aws_resource_for_service_name(profile_name=env, service_name="s3")
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def check_key_exists(self, s3_key_to_check: str) -> Optional[bool]:
+    def check_key_exists(self, s3_key_to_check: str) -> "Optional[bool]":
         """
         check_key_exists - Checks if an S3 key exists
         :param s3_key_to_check:
@@ -56,8 +56,7 @@ class S3Connector(ILogger):
         else:
             return True
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def get_object_by_etag(self, bucket_relative_file_name: str, etag: str) -> object:
+    def get_object_by_etag(self, bucket_relative_file_name: str, etag: str) -> "Optional[object]":
         """
         get_object_by_etag - Gets S3 object by its ETag header if it. exists
         :param bucket_relative_file_name: The name of the file in the bucket (relative)
@@ -75,9 +74,9 @@ class S3Connector(ILogger):
                 self._logger.error(
                     "Failed to check ETag: " + str(etag) + " existence in bucket " + str(self.bucket_name)
                 )
-        return
+        return None
 
-    def create_bucket(self, s3_client: boto3.Session.client = None) -> bool:
+    def create_bucket(self, s3_client: "Any" = None) -> bool:
         """
         Creates a bucket with the initialized bucket name.
         :return: The new bucket response
@@ -107,12 +106,16 @@ class S3Connector(ILogger):
             self._logger.fatal(f'Failed to create bucket "{self.bucket_name}": {err}')
             raise err
 
-    def check_bucket_exists(self, bucket_name: str = None, s3_resource: boto3.Session.resource = None) -> bool:
+    def check_bucket_exists(
+        self,
+        bucket_name: "Optional[str]" = None,
+        s3_resource: "Any" = None,
+    ) -> bool:
         resource = s3_resource or self.s3_resource
         bucket_name = bucket_name if bucket_name else self.bucket_name
-        return resource.Bucket(bucket_name) in resource.buckets.all()
+        return resource.Bucket(bucket_name) in resource.buckets.all()  # type: ignore[union-attr]
 
-    def delete_bucket(self, s3_resource: boto3.Session.resource = None):
+    def delete_bucket(self, s3_resource: "Any" = None) -> bool:
         """
         Deletes a bucket with the initialized bucket name.
         :return: True if succeeded.
@@ -121,7 +124,7 @@ class S3Connector(ILogger):
         resource = s3_resource or self.s3_resource
         try:
             self._logger.info("Deleting Bucket: " + self.bucket_name + " from S3")
-            bucket = resource.Bucket(self.bucket_name)
+            bucket = resource.Bucket(self.bucket_name)  # type: ignore[union-attr]
             bucket.objects.all().delete()
             bucket.delete()
             self._logger.debug("Successfully Deleted Bucket: " + self.bucket_name + " from S3")
@@ -130,8 +133,7 @@ class S3Connector(ILogger):
             raise ex
         return True
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def get_object_metadata(self, s3_key: str):
+    def get_object_metadata(self, s3_key: str) -> "Dict[str, Any]":
         try:
             return self.s3_client.head_object(Bucket=self.bucket_name, Key=s3_key)
         except botocore.exceptions.ClientError as ex:
@@ -141,7 +143,6 @@ class S3Connector(ILogger):
                 raise KeyNotExistInBucketError(msg)
             raise ex
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
     def delete_key(self, s3_key_to_delete: str) -> bool:
         """
         delete_key - Deletes a Key from an S3 Bucket
@@ -164,8 +165,7 @@ class S3Connector(ILogger):
 
         return True
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def upload_file_from_stream(self, file, key: str):
+    def upload_file_from_stream(self, file: bytes, key: str) -> bool:
         """
         upload_file - Uploads a file to S3 via boto3 interface
                       *Please Notice* - This method is for working with files, not objects
@@ -175,8 +175,8 @@ class S3Connector(ILogger):
         """
         try:
             self._logger.debug("Uploading Key: " + key + " to S3 bucket: " + self.bucket_name)
-            buffer = BytesIO(file)
-            self.upload_buffer(key, buffer)
+            _buffer = BytesIO(file)
+            self.upload_buffer(key, _buffer)
             return True
         except Exception as ex:
             self._logger.critical(
@@ -189,8 +189,7 @@ class S3Connector(ILogger):
             )
             return False
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def upload_file(self, filename_to_upload: str, key: str):
+    def upload_file(self, filename_to_upload: str, key: str) -> bool:
         """
         upload_file - Uploads a file to S3 via boto3 interface
                       *Please Notice* - This method is for working with files, not objects
@@ -215,7 +214,7 @@ class S3Connector(ILogger):
             )
             return False
 
-    def create_folder(self, folder_name: str):
+    def create_folder(self, folder_name: str) -> bool:
         """
         :param folder_name: name of the folder to create.
         :return: bool - true if creation succeeded
@@ -232,7 +231,7 @@ class S3Connector(ILogger):
             )
             return False
 
-    def rename_key(self, source_key: str, destination_key: str):
+    def rename_key(self, source_key: str, destination_key: str) -> bool:
         self.copy_key(self.bucket_name, source_key=source_key, destination_key=destination_key)
         try:
             delete_success = self.delete_key(s3_key_to_delete=source_key)
@@ -244,7 +243,6 @@ class S3Connector(ILogger):
                 f"Failed to remove old key {source_key} after creating new copy with new name {destination_key}. "
             ) from e
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
     def download_key(self, target_path: str, key_to_download: str) -> bool:
         """
         download_file - Downloads a key from S3 using boto3 to the provided filename
@@ -272,10 +270,12 @@ class S3Connector(ILogger):
 
         return True
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
     def download_keys_by_prefix(
-        self, s3_bucket_path_prefix: str, local_download_dir: str, s3_file_path_prefix: str = ""
-    ):
+        self,
+        s3_bucket_path_prefix: str,
+        local_download_dir: str,
+        s3_file_path_prefix: str = "",
+    ) -> None:
         """
         download_keys_by_prefix - Download all the keys who match the provided in-bucket path prefix and file prefix
             :param s3_bucket_path_prefix:   The S3 "folder" to download from
@@ -298,8 +298,7 @@ class S3Connector(ILogger):
             local_filename = key_to_download.split("/")[-1]
             self.download_key(target_path=local_download_dir + "/" + local_filename, key_to_download=key_to_download)
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def download_file_by_path(self, s3_file_path: str, local_download_dir: str):
+    def download_file_by_path(self, s3_file_path: str, local_download_dir: str) -> str:
         """
         :param s3_file_path: str - path ot s3 file e.g./ "s3://x/y.zip"
         :param local_download_dir: path to download
@@ -313,8 +312,7 @@ class S3Connector(ILogger):
         self.download_key(target_path=local_download_dir + "/" + local_filename, key_to_download=s3_file_path)
         return local_filename
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def empty_folder_content_by_path_prefix(self, s3_bucket_path_prefix) -> list:
+    def empty_folder_content_by_path_prefix(self, s3_bucket_path_prefix: str) -> "List[Dict[str, Any]]":
         """
         empty_folder_content_by_path_prefix - Deletes all the files in the specified bucket path
             :param s3_bucket_path_prefix: The "folder" to empty
@@ -323,8 +321,8 @@ class S3Connector(ILogger):
         paginator = self.s3_client.get_paginator("list_objects")
         page_iterator = paginator.paginate(Bucket=self.bucket_name, Prefix=s3_bucket_path_prefix)
 
-        files_dict_to_delete = dict(Objects=[])
-        errors_list = []
+        files_dict_to_delete: "Dict[str, Any]" = dict(Objects=[])
+        errors_list: "List[Dict[str, Any]]" = []
 
         for item in page_iterator.search("Contents"):
             if item is not None:
@@ -343,7 +341,11 @@ class S3Connector(ILogger):
 
         return errors_list
 
-    def _delete_files_left_in_list(self, errors_list, files_dict_to_delete):
+    def _delete_files_left_in_list(
+        self,
+        errors_list: "List[Dict[str, Any]]",
+        files_dict_to_delete: "Dict[str, Any]",
+    ) -> None:
         try:
             s3_response = self.s3_client.delete_objects(Bucket=self.bucket_name, Delete=files_dict_to_delete)
         except Exception as ex:
@@ -357,15 +359,14 @@ class S3Connector(ILogger):
         if "Errors" in s3_response:
             errors_list.append(s3_response["Errors"])
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def upload_buffer(self, new_key_name: str, buffer_to_write: StringIO):
+    def upload_buffer(self, new_key_name: str, buffer_to_write: "Union[StringIO, BytesIO]") -> None:
         """
         Uploads a buffer into a file in S3 with the provided key name.
         :bucket: The name of the bucket
         :new_key_name: The name of the file to create in s3
         :buffer_to_write: A buffer that contains the file contents.
         """
-        self.s3_resource.Object(self.bucket_name, new_key_name).put(Body=buffer_to_write.getvalue())
+        self.s3_resource.Object(self.bucket_name, new_key_name).put(Body=buffer_to_write.getvalue())  # type: ignore[union-attr]
 
     def upload_empty_file(self, key_name: str) -> None:
         """
@@ -375,8 +376,7 @@ class S3Connector(ILogger):
         """
         self.upload_buffer(new_key_name=key_name, buffer_to_write=StringIO())
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
-    def list_bucket_objects(self, prefix: str = None) -> List[dict]:
+    def list_bucket_objects(self, prefix: "Optional[str]" = None) -> "List[Dict[str, Any]]":
         """
         Gets a list of dictionaries, representing files in the S3 bucket that is passed in the constructor (self.bucket).
         :param prefix: A prefix filter for the files names.
@@ -395,10 +395,14 @@ class S3Connector(ILogger):
             bucket_objects.append(item)
         return bucket_objects
 
-    @explicit_params_validation(validation_type="NoneOrEmpty")
     def create_presigned_upload_url(
-        self, object_name: str, fields=None, conditions=None, expiration=3600, override: bool = False
-    ):
+        self,
+        object_name: str,
+        fields: "Any" = None,
+        conditions: "Any" = None,
+        expiration: int = 3600,
+        override: bool = False,
+    ) -> "Dict[str, Any]":
         """Generate a presigned URL S3 POST request to upload a file
         :param object_name: string
         :param fields: Dictionary of prefilled form fields
@@ -420,7 +424,12 @@ class S3Connector(ILogger):
         )
         return response
 
-    def create_presigned_download_url(self, object_name: str, expiration=3600, download_name: str = None):
+    def create_presigned_download_url(
+        self,
+        object_name: str,
+        expiration: int = 3600,
+        download_name: "Optional[str]" = None,
+    ) -> str:
         """Generate a presigned URL S3 Get request to download a file
         :param object_name: string
         :param expiration: Time in seconds for the presigned URL to remain valid
@@ -443,16 +452,16 @@ class S3Connector(ILogger):
         return response
 
     @staticmethod
-    def convert_content_length_to_mb(content_length):
+    def convert_content_length_to_mb(content_length: int) -> float:
         return round(float(f"{content_length / (1e+6):2f}"), 2)
 
-    def copy_key(self, destination_bucket_name: str, source_key: str, destination_key: str):
+    def copy_key(self, destination_bucket_name: str, source_key: str, destination_key: str) -> bool:
         self._logger.info(
             f"Copying the bucket object {self.bucket_name}/{source_key} to {destination_bucket_name}/{destination_key}"
         )
         copy_source = {"Bucket": self.bucket_name, "Key": source_key}
 
         # Copying the key
-        bucket = self.s3_resource.Bucket(destination_bucket_name)
+        bucket = self.s3_resource.Bucket(destination_bucket_name)  # type: ignore[union-attr]
         bucket.copy(copy_source, destination_key)
         return True
