@@ -20,7 +20,6 @@ class HardwareType(str, Enum):
     A10G = "A10G"
     A100_80G = "A100 80GB GCP"
     A100_40G = "A100 40GB GCP"
-    CPU = "CPU"
     EPYC = "EPYC"
     EPYC_7002 = "EPYC 7002"
     EPYC_7003 = "EPYC 7003"
@@ -30,6 +29,7 @@ class HardwareType(str, Enum):
     ORIN = "Jetson Orin"
     ORIN_NX = "Jetson Orin NX"
     ORIN_NANO = "Jetson Orin Nano"
+    ORIN_NANO_4G = "Jetson Orin Nano 4GB"
     CASCADE_LAKE = "Cascade Lake"
     SKYLAKE = "Skylake"
     Broadwell = "Broadwell"
@@ -37,6 +37,7 @@ class HardwareType(str, Enum):
     NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
     SKYLAKE_SP = "Skylake-SP"
     CASCADE_LAKE_GCP = "Cascade Lake GCP"
+    IMX8 = "NXP i.MX 8M mini"
 
     HAILO8 = "Hailo-8"
     AMBARELLA = "Ambarella"
@@ -74,11 +75,7 @@ class HardwareType(str, Enum):
 
     @property
     def is_deprecated(self) -> bool:
-        return self in [
-            HardwareType.K80,
-            HardwareType.CPU,
-            HardwareType.EPYC,
-        ]
+        return self in [HardwareType.K80, HardwareType.EPYC]
 
 
 class HardwareGroup(str, Enum):
@@ -94,10 +91,6 @@ class HardwareMachineModel(str, Enum):
     T4 = "g4dn.2xlarge"
     A10G = "g5.2xlarge"
     EPYC = "c5a.2xlarge"
-    # CPU is deprecated, cascade_lake is relevant,
-    # python aliases duplicate enum values to the first key to use them,
-    # so cascade_lake should be before cpu. cpu's label will be broken :(, but that's fine.
-    # the reverse isn't.
     CASCADE_LAKE = "c5.4xlarge"
     SKYLAKE = "c5n.4xlarge"
     Broadwell = "m4.4xlarge"
@@ -114,8 +107,10 @@ class HardwareMachineModel(str, Enum):
     ORIN = HardwareType.ORIN.value
     ORIN_NX = HardwareType.ORIN_NX.value
     ORIN_NANO = HardwareType.ORIN_NANO.value
+    ORIN_NANO_4G = HardwareType.ORIN_NANO_4G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
     A100_80G = HardwareType.A100_80G.value
+    IMX8 = HardwareType.IMX8.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
     APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
@@ -131,9 +126,6 @@ class HardwareMachineModel(str, Enum):
     EXYNOS_990 = HardwareType.EXYNOS_990.value
     EXYNOS_2200 = HardwareType.EXYNOS_2200.value
 
-    # deprecated
-    CPU = "c5.4xlarge"
-
 
 class InferenceHardware(str, Enum):
     """
@@ -158,9 +150,9 @@ class MapHardwareTypeToFamily(str, Enum):
     ORIN = InferenceHardware.GPU.value
     ORIN_NX = InferenceHardware.GPU.value
     ORIN_NANO = InferenceHardware.GPU.value
+    ORIN_NANO_4G = InferenceHardware.GPU.value
 
     # CPUs
-    CPU = InferenceHardware.CPU.value
     EPYC = InferenceHardware.CPU.value
     EPYC_7002 = InferenceHardware.CPU.value
     EPYC_7003 = InferenceHardware.CPU.value
@@ -171,6 +163,7 @@ class MapHardwareTypeToFamily(str, Enum):
     NUC_TIGER_LAKE = InferenceHardware.CPU.value
     SKYLAKE_SP = InferenceHardware.CPU.value
     CASCADE_LAKE_GCP = InferenceHardware.CPU.value
+    IMX8 = InferenceHardware.CPU.value
 
 
 class InferyVersion(str, Enum):
@@ -192,14 +185,14 @@ class MapHardwareTypeToInferyVersion(str, Enum):
 
     # Jetsons
     NANO = InferyVersion.JETSON_PY36.value
-    XAVIER = InferyVersion.JETSON_PY36.value
+    XAVIER = InferyVersion.JETSON_PY38.value
     XAVIER_AGX = InferyVersion.JETSON_PY36.value
     ORIN = InferyVersion.JETSON_PY38.value
     ORIN_NX = InferyVersion.JETSON_PY38.value
     ORIN_NANO = InferyVersion.JETSON_PY38.value
+    ORIN_NANO_4G = InferyVersion.JETSON_PY38.value
 
     # CPUs
-    CPU = InferyVersion.CPU.value
     EPYC = InferyVersion.CPU.value
     EPYC_7002 = InferyVersion.CPU.value
     EPYC_7003 = InferyVersion.CPU.value
@@ -210,6 +203,7 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     NUC_TIGER_LAKE = InferyVersion.CPU.value
     SKYLAKE_SP = InferyVersion.CPU.value
     CASCADE_LAKE_GCP = InferyVersion.CPU.value
+    IMX8 = InferyVersion.CPU.value
 
 
 class HardwareEnvironment(str, Enum):
@@ -223,6 +217,7 @@ class HardwareVendor(str, Enum):
     INTEL = "intel"
     NVIDIA = "nvidia"
     AMD = "amd"
+    NXP = "nxp"
 
 
 class HardwareTaint(str, Enum):
@@ -239,8 +234,8 @@ class HardwareTaint(str, Enum):
     ORIN = "nvidia.com/jetson-orin"
     ORIN_NX = "nvidia.com/jetson-orin-as-nx16"
     ORIN_NANO = "nvidia.com/jetson-orin-as-nano"
+    ORIN_NANO_4G = "nvidia.com/jetson-orin-as-nano4g"
     # CPUs
-    CPU = UNKNOWN
     EPYC = "amd.com/epyc"
     EPYC_7002 = "amd.com/7002"
     EPYC_7003 = "amd.com/7003"
@@ -251,6 +246,7 @@ class HardwareTaint(str, Enum):
     NUC_TIGER_LAKE = "intel.com/nuc-tiger-lake"
     SKYLAKE_SP = "intel.com/skylake-sp"
     CASCADE_LAKE_GCP = "intel.com/xeon"
+    IMX8 = UNKNOWN
 
 
 class HardwareLabel(str, Enum):
@@ -267,9 +263,9 @@ class HardwareLabel(str, Enum):
     ORIN = "nvidia-jetson-orin"
     ORIN_NX = "nvidia-jetson-orin-as-nx16"
     ORIN_NANO = "nvidia-jetson-orin-as-nano"
+    ORIN_NANO_4G = "nvidia-jetson-orin-as-nano4g"
 
     # CPUs
-    CPU = UNKNOWN
     EPYC = "amd-epyc"
     EPYC_7002 = "amd-epyc-7002"
     EPYC_7003 = "amd-epyc-7003"
@@ -280,6 +276,7 @@ class HardwareLabel(str, Enum):
     NUC_TIGER_LAKE = "intel-nuc-tiger-lake"
     SKYLAKE_SP = "intel-skylake-sp"
     CASCADE_LAKE_GCP = "intel-xeon"
+    IMX8 = UNKNOWN
 
 
 class MapHardwareTypeToVendor(str, Enum):
@@ -289,7 +286,6 @@ class MapHardwareTypeToVendor(str, Enum):
     A10G = HardwareVendor.NVIDIA.value
     A100_80G = HardwareVendor.NVIDIA.value
     A100_40G = HardwareVendor.NVIDIA.value
-    CPU = HardwareVendor.AMD.value
     EPYC = HardwareVendor.AMD.value
     EPYC_7002 = HardwareVendor.AMD.value
     EPYC_7003 = HardwareVendor.AMD.value
@@ -299,6 +295,7 @@ class MapHardwareTypeToVendor(str, Enum):
     ORIN = HardwareVendor.NVIDIA.value
     ORIN_NX = HardwareVendor.NVIDIA.value
     ORIN_NANO = HardwareVendor.NVIDIA.value
+    ORIN_NANO_4G = HardwareVendor.NVIDIA.value
     CASCADE_LAKE = HardwareVendor.INTEL.value
     SKYLAKE = HardwareVendor.INTEL.value
     Broadwell = HardwareVendor.INTEL.value
@@ -306,6 +303,7 @@ class MapHardwareTypeToVendor(str, Enum):
     NUC_TIGER_LAKE = HardwareVendor.INTEL.value
     SKYLAKE_SP = HardwareVendor.INTEL.value
     CASCADE_LAKE_GCP = HardwareVendor.INTEL.value
+    IMX8 = HardwareVendor.NXP.value
 
 
 class MapHardwareTypeToEnvironment(str, Enum):
@@ -314,7 +312,6 @@ class MapHardwareTypeToEnvironment(str, Enum):
     K80 = HardwareEnvironment.AWS.value
     T4 = HardwareEnvironment.AWS.value
     A10G = HardwareEnvironment.AWS.value
-    CPU = HardwareEnvironment.AWS.value
     EPYC = HardwareEnvironment.AWS.value
     EPYC_7002 = HardwareEnvironment.AWS.value
     EPYC_7003 = HardwareEnvironment.AWS.value
@@ -336,7 +333,9 @@ class MapHardwareTypeToEnvironment(str, Enum):
     ORIN = HardwareEnvironment.PREMISE.value
     ORIN_NX = HardwareEnvironment.PREMISE.value
     ORIN_NANO = HardwareEnvironment.PREMISE.value
+    ORIN_NANO_4G = HardwareEnvironment.PREMISE.value
     NUC_TIGER_LAKE = HardwareEnvironment.PREMISE.value
+    IMX8 = HardwareEnvironment.PREMISE.value
 
 
 class MapHardwareTypeToDefaultBatchSizeList(list, Enum):  # type: ignore[type-arg]
@@ -346,7 +345,6 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):  # type: ignore[type-ar
     A10G = get_enum_values(BatchSize)
     A100_80G = get_enum_values(BatchSize)
     A100_40G = get_enum_values(BatchSize)
-    CPU = get_enum_values(BatchSize)
     EPYC = get_enum_values(BatchSize)
     EPYC_7002 = get_enum_values(BatchSize)
     EPYC_7003 = get_enum_values(BatchSize)
@@ -356,6 +354,7 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):  # type: ignore[type-ar
     ORIN = get_enum_values(BatchSizeEdge)
     ORIN_NX = get_enum_values(BatchSizeEdge)
     ORIN_NANO = get_enum_values(BatchSizeEdge)
+    ORIN_NANO_4G = get_enum_values(BatchSizeEdge)
     CASCADE_LAKE = get_enum_values(BatchSize)
     SKYLAKE = get_enum_values(BatchSize)
     Broadwell = get_enum_values(BatchSize)
@@ -363,6 +362,7 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):  # type: ignore[type-ar
     NUC_TIGER_LAKE = get_enum_values(BatchSize)
     SKYLAKE_SP = get_enum_values(BatchSize)
     CASCADE_LAKE_GCP = get_enum_values(BatchSize)
+    IMX8 = get_enum_values(BatchSize)
 
 
 class HardwareImageRepository(str, Enum):
@@ -377,6 +377,7 @@ class MapHardwareTypeToImageRepository(str, Enum):
     ORIN = HardwareImageRepository.JETSON.value
     ORIN_NX = HardwareImageRepository.JETSON.value
     ORIN_NANO = HardwareImageRepository.JETSON.value
+    ORIN_NANO_4G = HardwareImageRepository.JETSON.value
     NUC_TIGER_LAKE = HardwareImageRepository.INTEL.value
 
 
@@ -397,11 +398,12 @@ class HardwareImageDistribution(str, Enum):
 
 class MapHardwareTypeToImageDistribution(str, Enum):
     NANO = HardwareImageDistribution.J46.value
-    XAVIER = HardwareImageDistribution.J46.value
+    XAVIER = HardwareImageDistribution.J502.value
     XAVIER_AGX = HardwareImageDistribution.J46.value
-    ORIN = HardwareImageDistribution.J50.value
+    ORIN = HardwareImageDistribution.J502.value
     ORIN_NX = HardwareImageDistribution.J502.value
     ORIN_NANO = HardwareImageDistribution.J502.value
+    ORIN_NANO_4G = HardwareImageDistribution.J502.value
 
 
 class MapHardwareTypeToGroup(str, Enum):
@@ -418,11 +420,12 @@ class MapHardwareTypeToGroup(str, Enum):
     ORIN = HardwareGroup.COMMERCIAL_EDGE.value
     ORIN_NX = HardwareGroup.COMMERCIAL_EDGE.value
     ORIN_NANO = HardwareGroup.COMMERCIAL_EDGE.value
+    ORIN_NANO_4G = HardwareGroup.COMMERCIAL_EDGE.value
     NUC_TIGER_LAKE = HardwareGroup.COMMERCIAL_EDGE.value
     AMBARELLA = HardwareGroup.COMMERCIAL_EDGE.value
     HAILO8 = HardwareGroup.COMMERCIAL_EDGE.value
+    IMX8 = HardwareGroup.COMMERCIAL_EDGE.value
 
-    CPU = HardwareGroup.CPU.value
     EPYC = HardwareGroup.CPU.value
     EPYC_7002 = HardwareGroup.CPU.value
     EPYC_7003 = HardwareGroup.CPU.value
@@ -458,10 +461,10 @@ class HardwareTypeLabel(str, Enum):
     ORIN = "Jetson AGX Orin Development Kit"
     ORIN_NX = "Jetson Orin NX 16GB"
     ORIN_NANO = "Jetson Orin Nano 8GB"
+    ORIN_NANO_4G = "Jetson Orin Nano 4GB"
     EPYC = type_with_model(HardwareMachineModel.EPYC)
     EPYC_7002 = type_with_model(HardwareMachineModel.EPYC_7002, f"AMD Rome {HardwareType.EPYC_7002.value}")
     EPYC_7003 = type_with_model(HardwareMachineModel.EPYC_7003, f"AMD Milan {HardwareType.EPYC_7003.value}")
-    # Cascade_lake must me above cpu, see comment above.
     CASCADE_LAKE = type_with_model(HardwareMachineModel.CASCADE_LAKE)
     SKYLAKE = type_with_model(HardwareMachineModel.SKYLAKE, "Sky Lake")
     Broadwell = type_with_model(HardwareMachineModel.Broadwell)
@@ -476,6 +479,7 @@ class HardwareTypeLabel(str, Enum):
 
     A100_80G = HardwareType.A100_80G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
+    IMX8 = HardwareType.IMX8.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
     APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
@@ -490,6 +494,3 @@ class HardwareTypeLabel(str, Enum):
     EXYNOS_9820 = HardwareType.EXYNOS_9820.value
     EXYNOS_990 = HardwareType.EXYNOS_990.value
     EXYNOS_2200 = HardwareType.EXYNOS_2200.value
-
-    # deprecated
-    CPU = type_with_model(HardwareMachineModel.CPU)
