@@ -1,9 +1,11 @@
-from enum import Enum
 from typing import TYPE_CHECKING
 from uuid import uuid4
 
 if TYPE_CHECKING:
-    from typing import Callable, Dict, List, Type
+    from typing import Callable, Dict, List, Type, TypeVar
+    from enum import Enum
+
+    T = TypeVar("T", bound=Enum)
 
 
 def get_random_uuid_string() -> str:
@@ -13,7 +15,7 @@ def get_random_uuid_string() -> str:
     return str(uuid4()).replace("-", "")
 
 
-def get_enum_values(enum_type: "Type[Enum]", filter_function: "Callable[[Enum], bool]" = lambda e: True) -> "List[str]":
+def get_enum_values(enum_type: "Type[T]", filter_function: "Callable[[T], bool]" = lambda e: True) -> "List[str]":
     """
     Gets all the possible enumerations of an enum.
     """
